#
# spec file for package python-Markups
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-Markups
Version:        4.1.0
Release:        1.1
Summary:        A wrapper around various text markups
License:        BSD-3-Clause
URL:            https://github.com/mitya57/pymarkups
Source:         https://files.pythonhosted.org/packages/source/m/markups/markups-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/retext-project/pymarkups/pull/20 adapt to Pygments 2.19
Patch:          pygments.patch
BuildRequires:  %{python_module Markdown >= 3}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-markdown-math}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module textile}
BuildRequires:  %{python_module wheel}
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-markdown-math
BuildArch:      noarch
%python_subpackages

%description
This module provides a wrapper around the various text markup languages,
such as Markdown and reStructuredText (these two are supported by default).

%prep
%autosetup -p1 -n markups-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%license LICENSE
%doc README.rst changelog
%{python_sitelib}/markups
%{python_sitelib}/Markups-%{version}*-info

%changelog
* Wed Jan 22 2025 Markéta Machová <mmachova@suse.com>
- Add pygments.patch to fix test failure with new pygments
* Wed Jan 22 2025 Markéta Machová <mmachova@suse.com>
- Update to 4.1.0
  * Incompatible change: Python 3.9 is no longer supported
  * Made the order of Markdown extensions deterministic
  * Adopted ruff for code quality checks and auto-formatting
* Tue Nov 12 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 4.0.0:
  Incompatible changes:
  - Python versions older than 3.9 are no longer supported.
  - Python-Markdown versions older than 3.0 are no longer supported.
  - Setuptools 61.2 or higher is required to build the project.
  - ``setup.py`` has been removed. Use ``pip``, ``build`` or other :PEP:`517`
    compatible tool.
  Other changes:
  - Added AsciiDocMarkup (contributed by Dave Kuhlman in #17).
  - Made the tests pass with Pygments ≥ 2.11.
  - Made the tests pass when PyYAML is not installed (#18).
  - Reformatted code in accordance with :PEP:`8` standard.
  - Fixed mypy errors and added a :PEP:`561` ``py.typed`` file.
- Update to 3.1.3:
  - Fixed logic to load extensions file when PyYAML module is not available
    (issue #16, thanks foxB612 for the bug report).
  - Made the tests pass with docutils 0.18.
- Update to 3.1.2:
  - Incompatible change: Python 3.6 is no longer supported.
  - Fixed replacing Markdown extensions in document.
  - Fixed crash when using TOC backrefs in reStructuredText (issue #14,
    thanks Hrissimir for the patch).
- Update to 3.1.1:
  - The reStructuredText markup now includes line numbers information in
    ``data-posmap`` attributes.
  - The reStructuredText markup now uses only ``minimal.css`` stylesheet
    (not ``plain.css`` anymore).
  - Added support for the upcoming docutils 0.17 release to the tests.
- Update to 3.1.0:
  Incompatible changes:
  - Python versions older than 3.6 are no longer supported.
  Other changes:
  - Instead of ``pkg_resources``, ``importlib.metadata`` is now used.
  - For Markdown markup, ``markdown-extensions.yaml`` files are now supported
    in addition to ``markdown-extensions.txt`` files.
  - Type annotations were added for public API.
  - The reStructuredText markup no longer raises exceptions for invalid markup.
  - MathJax v3 is now supported in addition to v2. Also, the Arch Linux mathjax
    packages are now supported (issue #4).
  - Added Pygments CSS support for the ``pymdownx.highlight`` Markdown extension.
* Wed May 26 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Wed Jan  2 2019 badshah400@gmail.com
- Update to version 3.0.0:
  * The deprecated AbstractMarkup API has been removed.
  * Python 3.2 is no longer supported.
  * The output now uses HTML5 instead of HTML4.
  * The custom markups are now registered with entry points.
  * The ``get_custom_markups()`` method has been removed.
  * New required dependency: python-markdown-math.
  * Python-Markdown 3.x release is now supported.
- Add python-markdown-math to Requires (new dependency).
- Run fdupes to clean up duplicate files wasting space (add
  BuildRequires: fdupes).
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 31 2017 toddrme2178@gmail.com
- update to Version 2.0.1
  * The new MathJax CDN is used, the old one will be shut down soon.
  * When using MathJax with Markdown, the AMSmath and AMSsymbols extensions are
    now enabled.
- update to Version 2.0.0, 2016-05-09
  * Changed the API of pymarkups to clearly separate the conversion step from
    access to the various elements of the result. The old API is deprecated
    and will be removed in a future release. Please see the documentation for
    details on using the new API.
  * The reStructuredText markup now includes document title and subtitle in
    the HTML body.
  * Added a ``markup2html.py`` reference script to show API usage.
  * Improved support for specifying Markdown extensions in the document.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu May  7 2015 benoit.monin@gmx.fr
- update to version 0.6.1:
  * PyMarkups now uses warnings system instead of printing messages
    to stderr
  * Improvements to Markdown markup:
    + Fixed parsing math that contains nested environments
    + Fixed crash on extensions names starting with dot
  * Miscellaneous fixes
- additional changes from version 0.6:
  * Custom markups are now normal Python modules
  * Web module no longer supports Python 2.x
  * Refactor the code related to Markdown extensions to make it
    work with upcoming Python-Markdown releases
  * MathJax extension is now in a separate module
- additional changes from version 0.5.2:
  * Fixed loading of Markdown extensions with options
- additional changes from version 0.5.1:
  * Fixed Markdown markup crash on empty files
  * Include documentation in the tarballs
  * Testsuite improvements
- additional changes from version 0.5:
  * Improvements to Markdown markup:
    + All math delimeters except $...$ are now enabled by default
    + remove_extra extension now disables formulas support
    + It is now possible to specify required extensions in the
    first line of the file
  * Add Sphinx documentation
- additional changes from version 0.4:
  * Add Textile markup
  * reStructuredText markup now supports file names and settings
    overrides
  * Web module now raises WebUpdateError when updating fails
- additional changes from version 0.3:
  * MathJax support in Markdown has been improved and no longer
    relies on tex2jax extension
  * It is now possible to pass extensions list to MarkdownMarkup
    constructor
  * Pygments style is now configurable
  * Testsuite improvements
- update project URL
- add python-importlib as a dependency for SLE11
- rename README to README.rst: changed upstream
* Wed Feb  6 2013 saschpe@suse.de
- Completely redone spec file
* Sat Feb  2 2013 i@marguerite.su
- initial version 0.2.4
  * no changelog for this version (yet).
